@@ -21,6 +21,18 @@
 
 #include "vimagewidget.h"
 
+static QPixmap pixmapFromFile(const QString &name)
+{
+    QPixmap pixmap;
+
+    if (!QPixmapCache::find(name, pixmap)) {
+	pixmap = QPixmap(QString("/opt/viito/data/%1").arg(name));
+	QPixmapCache::insert(name, pixmap);
+    }
+
+    return pixmap;
+}
+
 VImageWidget::VImageWidget(QWidget *parent)
     : QWidget(parent)
 {
@@ -29,7 +41,8 @@ VImageWidget::VImageWidget(QWidget *parent)
     mAuthor = new QLabel(this);
     mImage = new QLabel(this);
 
-    mAuthor->setStyleSheet("color: black; background-color: white");
+    mAuthor->setStyleSheet("color: black; background-color: white; "
+			   "font-size: 14px");
     mAuthor->setAlignment(Qt::AlignBottom | Qt::AlignRight);
     mImage->setAlignment(Qt::AlignCenter);
 
@@ -38,23 +51,21 @@ VImageWidget::VImageWidget(QWidget *parent)
 
     grabGesture(Qt::SwipeGesture);
 
+    connect(QApplication::desktop(), SIGNAL(resized(int)),
+	    this, SLOT(orientationChanged()));
+
     setStyleSheet("background-color: white");
 
     setWindowFlags(windowFlags() | Qt::Window);
     setAttribute(Qt::WA_Maemo5StackedWindow);
-
-    connect(QApplication::desktop(), SIGNAL(resized(int)),
-	    this, SLOT(orientationChanged()));
 }
 
-void VImageWidget::setAuthor(const QString &author)
+void VImageWidget::setImage(const QString &path, const QString &author)
 {
+    mPixmap = pixmapFromFile(path);
     mAuthor->setText(author);
-}
 
-void VImageWidget::setPixmap(const QPixmap &pixmap)
-{
-    mImage->setPixmap(pixmap);
+    orientationChanged();
 }
 
 bool VImageWidget::event(QEvent *event)
@@ -63,6 +74,8 @@ bool VImageWidget::event(QEvent *event)
 	return gestureEvent(static_cast<QGestureEvent*>(event));
     else if (event->type() == QEvent::KeyPress)
 	return keyboardEvent(static_cast<QKeyEvent*>(event));
+    else if (event->type() == QEvent::MouseButtonPress)
+	return screentapEvent(static_cast<QMouseEvent*>(event));
     else
 	return QWidget::event(event);
 }
@@ -78,6 +91,18 @@ bool VImageWidget::keyboardEvent(QKeyEvent *event)
     return true;
 }
 
+bool VImageWidget::screentapEvent(QMouseEvent *event)
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+
+    if (event->globalX() > screenGeometry.width() / 2)
+	emit next();
+    else
+	emit previous();
+
+    return true;
+}
+
 bool VImageWidget::gestureEvent(QGestureEvent *event)
 {
     QGesture *swipe = event->gesture(Qt::SwipeGesture);
@@ -102,11 +127,16 @@ bool VImageWidget::handleSwipe(QSwipeGesture *swipe)
     return true;
 }
 
-void VImageWidget::orientationChanged()
+bool VImageWidget::isLandscape()
 {
     QRect screenGeometry = QApplication::desktop()->screenGeometry();
-    if (screenGeometry.width() > screenGeometry.height())
-	qDebug() << "In landscape mode.";
+    return screenGeometry.width() > screenGeometry.height();
+}
+
+void VImageWidget::orientationChanged()
+{
+    if (isLandscape())
+	mImage->setPixmap(mPixmap.scaledToHeight(400, Qt::SmoothTransformation));
     else
-	qDebug() << "In portrait mode.";
+	mImage->setPixmap(mPixmap.scaledToWidth(480, Qt::SmoothTransformation));
 }
