@@ -19,13 +19,6 @@
 
 #include <QtGui>
 #include <QDomDocument>
-#include <QFile>
-#include <QListView>
-#include <QStandardItemModel>
-#include <QPixmapCache>
-#include <QPixmap>
-#include <QLabel>
-#include <QDebug>
 
 #include "vmainwindow.h"
 #include "vimagewidget.h"
@@ -54,42 +47,28 @@ static QDomDocument readXmlDocument(const QString &fileName)
     return doc;
 }
 
-static QPixmap pixmapFromFile(const QString &name)
-{
-    QPixmap pixmap;
 
-    if (!QPixmapCache::find(name, pixmap)) {
-	pixmap = QPixmap(QString("/opt/viito/data/%1").arg(name));
-	QPixmapCache::insert(name, pixmap);
-    }
-
-    return pixmap;
-}
 
 VMainWindow::VMainWindow()
     : QMainWindow()
 {
+    setAttribute(Qt::WA_Maemo5StackedWindow);
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 }
 
 VMainWindow::VMainWindow(const QString &file)
     : QMainWindow()
 {
-    QDomDocument doc = readXmlDocument(file);
-    setModel(doc);
+    setAttribute(Qt::WA_Maemo5StackedWindow);
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
-    mTopicView = new QListView(this);
-    mTopicView->setModel(mTopicModel);
+    createModels(readXmlDocument(file));
 
-    /* TODO: Make this a completely separate window, and have it
-     * launch a separate image view. */
-    mSearchView = new QListView(this);
-    mSearchView->setModel(mSearchModel);
-    mSearchView->setWindowFlags(mSearchView->windowFlags() | Qt::Window);
-    mSearchView->setAttribute(Qt::WA_Maemo5StackedWindow);
-    mSearchView->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-    mSearchView->setWindowTitle(tr("All words"));
+    QListView *mainView = new QListView(this);
+    mainView->setModel(mDataModel);
+    setCentralWidget(mainView);
 
-    mImageView = new QListView(this);
+    mImageView = new QListView(mainView);
     mImageView->setWindowFlags(mImageView->windowFlags() | Qt::Window);
     mImageView->setAttribute(Qt::WA_Maemo5StackedWindow);
     mImageView->setAttribute(Qt::WA_Maemo5AutoOrientation, true);
@@ -97,38 +76,22 @@ VMainWindow::VMainWindow(const QString &file)
     mImageWidget = new VImageWidget(mImageView);
 
     QAction *aboutAction = new QAction(tr("About"), this);
-    QAction *searchAction = new QAction(tr("Search"), this);
-
     menuBar()->addAction(aboutAction);
-    menuBar()->addAction(searchAction);
 
     connect(aboutAction, SIGNAL(triggered()), this, SLOT(about()));
-    connect(searchAction, SIGNAL(triggered()), this, SLOT(search()));
-
-    connect(mTopicView, SIGNAL(clicked(const QModelIndex&)),
+    connect(mainView, SIGNAL(clicked(const QModelIndex&)),
 	    this, SLOT(topicClicked(const QModelIndex&)));
-
-    connect(mSearchView, SIGNAL(clicked(const QModelIndex&)),
-	    this, SLOT(imageClicked(const QModelIndex&)));
-
     connect(mImageView, SIGNAL(clicked(const QModelIndex&)),
 	    this, SLOT(imageClicked(const QModelIndex&)));
-
     connect(mImageWidget, SIGNAL(next()),
 	    this, SLOT(nextImage()));
-
     connect(mImageWidget, SIGNAL(previous()),
 	    this, SLOT(previousImage()));
-
-    setAttribute(Qt::WA_Maemo5StackedWindow);
-    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-    setCentralWidget(mTopicView);
 }
 
-void VMainWindow::setModel(const QDomDocument &doc)
+void VMainWindow::createModels(const QDomDocument &doc)
 {
-    mTopicModel = new QStandardItemModel;
-    mSearchModel = new QStandardItemModel;
+    mDataModel = new QStandardItemModel(this);
 
     QDomNodeList topics = doc.elementsByTagName("topic");
 
@@ -142,19 +105,20 @@ void VMainWindow::setModel(const QDomDocument &doc)
 
 	QDomNodeList images = node.childNodes();
 
-	VStandardItem *topic = new VStandardItem(name);
+	QStandardItem *topic = new QStandardItem(name);
 	topic->setTextAlignment(Qt::AlignCenter);
 	topic->setEditable(false);
 
 	QStandardItemModel *imageModel = new QStandardItemModel;
-	topic->setData(qVariantFromValue((void *)imageModel), VMainWindow::ModelRole);
+	topic->setData(qVariantFromValue((void *)imageModel),
+		       VMainWindow::ModelRole);
 
 	for (int j = 0; j < images.count(); j++) {
 
 	    QDomNamedNodeMap imgattrs = images.at(j).attributes();
-	    VStandardItem *image;
+	    QStandardItem *image;
 
-	    image = new VStandardItem(imgattrs.namedItem("name").nodeValue());
+	    image = new QStandardItem(imgattrs.namedItem("name").nodeValue());
 
 	    image->setData(imgattrs.namedItem("author").nodeValue(),
 			   VMainWindow::AuthorRole);
@@ -165,13 +129,11 @@ void VMainWindow::setModel(const QDomDocument &doc)
 	    image->setEditable(false);
 
 	    imageModel->appendRow(image);
-	    mSearchModel->appendRow(image->clone());
 	}
-	imageModel->sort(Qt::AscendingOrder);
-	mTopicModel->appendRow(topic);
+	imageModel->sort(0);
+	mDataModel->appendRow(topic);
     }
-    mTopicModel->sort(Qt::AscendingOrder);
-    mSearchModel->sort(Qt::AscendingOrder);
+    mDataModel->sort(0);
 }
 
 void VMainWindow::topicClicked(const QModelIndex &index)
@@ -207,11 +169,10 @@ void VMainWindow::setImage(const QModelIndex &index, int offset)
 
     QString author = QString(" %1").arg(next.data(AuthorRole).toString());
     QString title = next.data().toString();
-    QPixmap pixmap = pixmapFromFile(next.data(PathRole).toString());
+    QString path = next.data(PathRole).toString();
 
     mImageWidget->setWindowTitle(title);
-    mImageWidget->setPixmap(pixmap);
-    mImageWidget->setAuthor(author);
+    mImageWidget->setImage(path, author);
 }
 
 void VMainWindow::nextImage()
@@ -227,10 +188,13 @@ void VMainWindow::previousImage()
 void VMainWindow::about()
 {
     QMessageBox::information(this, tr("About Viito"),
-			     tr("Copyright  2010 Aki Niemi"));
-}
-
-void VMainWindow::search()
-{
-    mSearchView->show();
+			     tr("Viito is a free and open source sign "
+				"language image dictionary application."
+				"\n\n"
+				"Copyright  2010 Aki Niemi"
+				"\n\n"
+				"Source for image data:\n"
+				"Papunetin kuvapankki, "
+				"http://www.papunet.fi, Elina Vanninen "
+				"and Kalevi Puistolinna."));
 }
