@@ -21,7 +21,6 @@
 #define VMAINWINDOW_H
 
 #include <QMainWindow>
-#include <QStandardItem>
 
 class QString;
 class QModelIndex;
@@ -31,21 +30,6 @@ class QLabel;
 class QStandardItemModel;
 class VImageWidget;
 
-class VStandardItem : public QStandardItem
-{
-
-public:
-    VStandardItem() : QStandardItem() {}
-    VStandardItem(const QString &text) : QStandardItem(text) {}
-    VStandardItem(const QStandardItem &other) : QStandardItem(other) {}    
-
-private:
-    bool operator<(const QStandardItem &other)
-    {
-	return text().toLower() < other.text().toLower();
-    }
-};
-
 class VMainWindow : public QMainWindow
 {
     Q_OBJECT
@@ -63,24 +47,17 @@ public:
 private slots:
     void topicClicked(const QModelIndex &index);
     void imageClicked(const QModelIndex &index);
-
     void nextImage();
     void previousImage();
     void about();
-    void search();
 
 private:
-    void setModel(const QDomDocument &doc);
+    void createModels(const QDomDocument &doc);
     void setImage(const QModelIndex &index, int offset=0);
 
-    QListView *mTopicView;
-    QListView *mSearchView;
     QListView *mImageView;
-
     VImageWidget *mImageWidget;
-
-    QStandardItemModel *mTopicModel;
-    QStandardItemModel *mSearchModel;
+    QStandardItemModel *mDataModel;
 };
 
 #endif // VMAINWINDOW_H
